@@ -10,14 +10,12 @@ import typing_extensions
 
 import aws_cdk._jsii
 import aws_cdk.aws_cognito_identitypool_alpha._jsii
+import cdk_nag._jsii
 import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/identity",
-    "0.2.16",
-    __name__[0:-6],
-    "identity@0.2.16.jsii.tgz",
+    "@aws-prototyping-sdk/identity", "0.3.4", __name__[0:-6], "identity@0.3.4.jsii.tgz"
 )
 
 __all__ = [
